@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0703';
+our $VERSION = '0.0800';
 
 use Moo;
 use strictures 2;
@@ -77,6 +77,12 @@ has horiz => (
 );
 
 
+has grid => (
+    is      => 'ro',
+    default => sub { 'blue' },
+);
+
+
 has fretboard => (
     is       => 'ro',
     init_arg => undef,
@@ -130,8 +136,8 @@ sub draw {
     }
 
     my $WHITE = 'white';
-    my $BLUE  = 'blue';
     my $BLACK = 'black';
+    my $GRID  = $self->grid;
     my $SPACE = $self->size;
 
     my @chord;
@@ -154,7 +160,7 @@ sub draw {
     # Draw the vertical string lines
     for my $string ( 0 .. $self->strings - 1 ) {
         $i->line(
-            color => $BLUE,
+            color => $GRID,
             x1    => $SPACE + $string * $SPACE,
             y1    => $SPACE,
             x2    => $SPACE + $string * $SPACE,
@@ -167,7 +173,7 @@ sub draw {
     # Draw the horizontal fret lines
     for my $fret ( 0 .. $self->frets - 1 ) {
         $i->line(
-            color => $BLUE,
+            color => $GRID,
             x1    => $SPACE,
             y1    => $SPACE + $fret * $SPACE,
             x2    => $SPACE + ($self->strings - 1) * $SPACE,
@@ -263,8 +269,8 @@ sub _draw_horiz {
     my ($self) = @_;
 
     my $WHITE = 'white';
-    my $BLUE  = 'blue';
     my $BLACK = 'black';
+    my $GRID  = $self->grid;
     my $SPACE = $self->size;
 
     my @chord;
@@ -287,7 +293,7 @@ sub _draw_horiz {
     # Draw the horizontal string lines
     for my $string ( 0 .. $self->strings - 1 ) {
         $i->line(
-            color => $BLUE,
+            color => $GRID,
             y1    => $SPACE + $string * $SPACE,
             x1    => $SPACE,
             y2    => $SPACE + $string * $SPACE,
@@ -300,7 +306,7 @@ sub _draw_horiz {
     # Draw the vertical fret lines
     for my $fret ( 0 .. $self->frets - 1 ) {
         $i->line(
-            color => $BLUE,
+            color => $GRID,
             y1    => $SPACE,
             x1    => $SPACE + $fret * $SPACE,
             y2    => $SPACE + ($self->strings - 1) * $SPACE,
@@ -418,7 +424,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0703
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -447,6 +453,7 @@ version 0.0703
     font     => '/path/to/TTF/font.ttf',
     tuning   => [qw/A E C G/],
     horiz    => 1,
+    grid     => 'gray',
     verbose  => 1,
   );
   $dia->draw;
@@ -576,6 +583,16 @@ Default: [ E B G D A E ]
 Draw the diagram horizontally.  That is, with the first string at the top and
 the 6th string at the bottom, and frets numbered from left to right.
 
+Default: 0
+
+=head2 grid
+
+  $grid = $dia->grid;
+
+The diagram grid (strings and frets) color.
+
+Default: blue
+
 =head2 fretboard
 
   $fretboard = $dia->fretboard;
@@ -641,7 +658,7 @@ L<Music::Chord::Namer>
 
 Similar modules:
 
-L<GD::Tab::Guitar>
+L<GD::Tab::Guitar> and L<GD::Tab::Ukulele>
 
 L<Music::Image::Chord>
 
